/* -*- mode: c++; c-basic-offset: 4; -*- */
#include "YPipe.hh"
#include "Interval.hh"

//======================================  Constructor
YPipe::YPipe(void) 
  : mStartTime(0)
{}

//======================================  Destructor
YPipe::~YPipe(void) {
}

//======================================  Get time delay
Interval
YPipe::getTimeDelay(void) const {
    return Interval(0.0);
}

//======================================  Test in use
bool
YPipe::inUse(void) const {
    return mStartTime != Time(0);
}
